#!/usr/bin/perl -w
#
#  PCC2 Server Console
#
#  This makes talking to a c2router a little easier. It reads lines
#  from standard input, and sends them to the c2router. The command
#  "S <n>" is interpreted locally, and used as a prefix for c2server
#  commands that need a session number.
#
#  FIXME: POST support
#

use Socket;
use IO::Handle;

my $cfg_port = 9999;
my $cfg_host = "localhost";

my $session;

$| = 1;

print "PCC2 Server Console\n> ";
while (<STDIN>) {
    chomp;
    my $cmd = $_;
    if ($cmd =~ /^s\s+(.+)/i) {
        $session = $1;
        print "Selected session '$1'.\n";
    } else {
        if (defined($session) && $cmd =~ /^(help|save|stat|get|post|quit)\b/) {
            $cmd = "S $session\n$cmd";
        }
        my $result = callServer($cmd);
        if ($result->[0] == 0) {
            print "ERROR: $result->[1]\n";
        } else {
            print "Result:\n";
            print map{"  $_"} @{$result->[1]};
        }
    }
    print "> ";
}
print "\n";



# Call server. Returns [0,error] or [1,[answer,....]].
sub callServer {
    my $query = shift;
    my $port = $cfg_port;
    my $ip = inet_aton($cfg_host)                               or return [0, "Unable to locate c2router: $!"];
    my $paddr = sockaddr_in($port, $ip);
    socket(SOCK, PF_INET, SOCK_STREAM, getprotobyname('tcp'))   or return [0, "Unable to create socket: $!"];
    SOCK->autoflush(1);
    connect(SOCK, $paddr)                                       or return [0, "Unable to connect to c2router: $!"];
    print SOCK "$query\n";
    my @reply;
    while (defined(my $line = <SOCK>)) {
        push @reply, $line;
    }
    close SOCK;
    [1, \@reply];
}
